==> haskell-network-uri-2.6.1.0-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS
key: network-uri-2.6.1.0-18L86fks2XD2OSuhve27bS
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
indefinite: False
exposed-modules:
    Network.URI
abi: 2690938855a63b0d59221887564a11f0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-uri-2.6.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-18L86fks2XD2OSuhve27bS
depends:
    base-4.10.1.0 deepseq-1.4.3.0
    parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-uri-2.6.1.0-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ
key: network-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
indefinite: False
exposed-modules:
    Network.URI
abi: 17ff77631878cfceba90438df04f39d6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-uri-2.6.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-6DCcjXT6KQAGJ7ruji2glJ
depends:
    base-4.10.1.0 deepseq-1.4.3.0
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
